@@ -507,11 +507,13 @@ class AkamaiPropertyManager():
         params['groupId'] = group_id
         if self.accountSwitchKey:
             params["accountSwitchKey"] = self.accountSwitchKey
-
-        getcpCodesJson = self._prdHttpCaller.getResult(ep,parameters=params)
-        print(getcpCodesJson)
-        for items in getcpCodesJson["cpcodes"]["items"]:
-            cpCodeList.append(items["cpcodeId"])
+        try:
+            getcpCodesJson = self._prdHttpCaller.getResult(ep,parameters=params)
+            for items in getcpCodesJson["cpcodes"]["items"]:
+                cpCodeList.append(items["cpcodeId"])
+        except Exception as e:
+            return []
+        return cpCodeList
 
     def getPropertiesofGroup(self,contractid,groupid):
         ep = '/papi/v1/properties'
@@ -520,15 +522,18 @@ class AkamaiPropertyManager():
         params['groupId'] = groupid
         if self.accountSwitchKey:
             params["accountSwitchKey"] = self.accountSwitchKey
-
-        getpropertiesJson = self._prdHttpCaller.getResult(ep,parameters=params)
         
-        propList = []
-        if len(getpropertiesJson['properties']['items']) != 0:
-            for prop in getpropertiesJson['properties']['items']:
-                propList.append(prop['propertyName'])
+        try: 
+            getpropertiesJson = self._prdHttpCaller.getResult(ep,parameters=params)
+            propList = []
+            if len(getpropertiesJson['properties']['items']) != 0:
+                for prop in getpropertiesJson['properties']['items']:
+                    propList.append(prop['propertyName'])
+            return propList
 
-        return propList
+        except Exception as e:
+            return []
+        
 
     def bulkSearch(self,jsonPathMatch,jsonPathQualifiers=None):
         bulkSearchEP = '/papi/v1/bulk/rules-search-requests-synch'
@@ -542,28 +547,64 @@ class AkamaiPropertyManager():
 
         json_data = json.dumps(data)
 
-        if self.accountSwitchKey:
-            params = {'accountSwitchKey':self.accountSwitchKey}
-            version_info = self._prdHttpCaller.postResult(bulkSearchEP,json_data,params)
-        else:
-            version_info = self._prdHttpCaller.postResult(bulkSearchEP,json_data)
+        try:
+            if self.accountSwitchKey:
+                params = {'accountSwitchKey':self.accountSwitchKey}
+                version_info = self._prdHttpCaller.postResult(bulkSearchEP,json_data,params)
+            else:
+                version_info = self._prdHttpCaller.postResult(bulkSearchEP,json_data)
 
-        propertiesList = []
-        if version_info[0] == 200:
-            for items in version_info[1]['results']:
-                propertiesList.append(items['propertyName'])
-            return propertiesList
-        else:
+            propertiesList = []
+            if version_info[0] == 200:
+                for items in version_info[1]['results']:
+                    propertiesList.append(items['propertyName'])
+                return propertiesList
+            else:
+                return []
+        except Exception as e:
             return []
     
     def getallProperties(self):
         propertylist = []
         groupIds = self.getGroups()
         contractIds = self.getContracts()
-        for grp in groupIds:
-            for ctr in contractIds:
+        for ctr in contractIds:
+            for grp in groupIds:
                 property_list = self.getPropertiesofGroup(ctr,grp)
                 if len(property_list) != 0:
                     for x in property_list:
                         propertylist.append(x)
-        return propertylist
\ No newline at end of file
+        return propertylist
+
+    def getCustomBehaviors(self):
+        cbList = {}
+        ep = '/papi/v1/custom-behaviors'
+        params = {}
+        if self.accountSwitchKey:
+            params["accountSwitchKey"] = self.accountSwitchKey
+        try:
+            getcbJson = self._prdHttpCaller.getResult(ep,parameters=params)
+            print(len(getcbJson["customBehaviors"]["items"]))
+            #print(getcbJson["customBehaviors"]["items"])
+            for item in getcbJson["customBehaviors"]["items"]:                
+                cbList[item['name']] =  item['behaviorId']
+            return cbList
+        except Exception as e:
+            print('Exception:',e)
+            return []
+
+
+    def getCustomOverrides(self):
+        coList = {}
+        ep = '/papi/v1/custom-overrides'
+        params = {}
+        if self.accountSwitchKey:
+            params["accountSwitchKey"] = self.accountSwitchKey
+        try:
+            getcoJson = self._prdHttpCaller.getResult(ep,parameters=params)
+            for items in getcoJson["customOverrides"]["items"]:
+                coList[items['name']] =  items['overrideId']
+            return coList
+        except Exception as e:
+            return []
+        
\ No newline at end of file
